/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __MALIIT_GLIB_MALIITCONTEXT_H__
#define __MALIIT_GLIB_MALIITCONTEXT_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for com.meego.inputmethod.inputcontext1 */

#define MALIIT_TYPE_CONTEXT (maliit_context_get_type ())
#define MALIIT_CONTEXT(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MALIIT_TYPE_CONTEXT, MaliitContext))
#define MALIIT_IS_CONTEXT(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MALIIT_TYPE_CONTEXT))
#define MALIIT_CONTEXT_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), MALIIT_TYPE_CONTEXT, MaliitContextIface))

struct _MaliitContext;
typedef struct _MaliitContext MaliitContext;
typedef struct _MaliitContextIface MaliitContextIface;

struct _MaliitContextIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_activation_lost_event) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_commit_string) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3);

  gboolean (*handle_im_initiated_hide) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_key_event) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    const gchar *arg_unnamed_arg3,
    gboolean arg_unnamed_arg4,
    gint arg_unnamed_arg5,
    guchar arg_unnamed_arg6);

  gboolean (*handle_notify_extended_attribute_changed) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gint arg_unnamed_arg0,
    const gchar *arg_unnamed_arg1,
    const gchar *arg_unnamed_arg2,
    const gchar *arg_unnamed_arg3,
    GVariant *arg_unnamed_arg4);

  gboolean (*handle_plugin_settings_loaded) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_unnamed_arg0);

  gboolean (*handle_preedit_rectangle) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_selection) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_set_detectable_auto_repeat) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_unnamed_arg0);

  gboolean (*handle_set_global_correction_enabled) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_unnamed_arg0);

  gboolean (*handle_set_language) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_unnamed_arg0);

  gboolean (*handle_set_redirect_keys) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_unnamed_arg0);

  gboolean (*handle_set_selection) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1);

  gboolean (*handle_update_input_method_area) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3);

  gboolean (*handle_update_preedit) (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_unnamed_arg0,
    GVariant *arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3,
    gint arg_unnamed_arg4);

};

GType maliit_context_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *maliit_context_interface_info (void);
guint maliit_context_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void maliit_context_complete_activation_lost_event (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_im_initiated_hide (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_commit_string (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_update_preedit (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_key_event (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_update_input_method_area (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_set_global_correction_enabled (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_preedit_rectangle (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gboolean unnamed_arg0,
    gint unnamed_arg1,
    gint unnamed_arg2,
    gint unnamed_arg3,
    gint unnamed_arg4);

void maliit_context_complete_set_redirect_keys (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_set_detectable_auto_repeat (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_set_selection (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_selection (
    MaliitContext *object,
    GDBusMethodInvocation *invocation,
    gboolean unnamed_arg0,
    const gchar *unnamed_arg1);

void maliit_context_complete_set_language (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_notify_extended_attribute_changed (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);

void maliit_context_complete_plugin_settings_loaded (
    MaliitContext *object,
    GDBusMethodInvocation *invocation);



/* D-Bus method calls: */
void maliit_context_call_activation_lost_event (
    MaliitContext *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_activation_lost_event_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_activation_lost_event_sync (
    MaliitContext *proxy,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_im_initiated_hide (
    MaliitContext *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_im_initiated_hide_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_im_initiated_hide_sync (
    MaliitContext *proxy,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_commit_string (
    MaliitContext *proxy,
    const gchar *arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_commit_string_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_commit_string_sync (
    MaliitContext *proxy,
    const gchar *arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_update_preedit (
    MaliitContext *proxy,
    const gchar *arg_unnamed_arg0,
    GVariant *arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3,
    gint arg_unnamed_arg4,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_update_preedit_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_update_preedit_sync (
    MaliitContext *proxy,
    const gchar *arg_unnamed_arg0,
    GVariant *arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3,
    gint arg_unnamed_arg4,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_key_event (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    const gchar *arg_unnamed_arg3,
    gboolean arg_unnamed_arg4,
    gint arg_unnamed_arg5,
    guchar arg_unnamed_arg6,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_key_event_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_key_event_sync (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    const gchar *arg_unnamed_arg3,
    gboolean arg_unnamed_arg4,
    gint arg_unnamed_arg5,
    guchar arg_unnamed_arg6,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_update_input_method_area (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_update_input_method_area_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_update_input_method_area_sync (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    gint arg_unnamed_arg2,
    gint arg_unnamed_arg3,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_set_global_correction_enabled (
    MaliitContext *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_set_global_correction_enabled_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_set_global_correction_enabled_sync (
    MaliitContext *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_preedit_rectangle (
    MaliitContext *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_preedit_rectangle_finish (
    MaliitContext *proxy,
    gboolean *out_unnamed_arg0,
    gint *out_unnamed_arg1,
    gint *out_unnamed_arg2,
    gint *out_unnamed_arg3,
    gint *out_unnamed_arg4,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_preedit_rectangle_sync (
    MaliitContext *proxy,
    gboolean *out_unnamed_arg0,
    gint *out_unnamed_arg1,
    gint *out_unnamed_arg2,
    gint *out_unnamed_arg3,
    gint *out_unnamed_arg4,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_set_redirect_keys (
    MaliitContext *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_set_redirect_keys_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_set_redirect_keys_sync (
    MaliitContext *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_set_detectable_auto_repeat (
    MaliitContext *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_set_detectable_auto_repeat_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_set_detectable_auto_repeat_sync (
    MaliitContext *proxy,
    gboolean arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_set_selection (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_set_selection_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_set_selection_sync (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    gint arg_unnamed_arg1,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_selection (
    MaliitContext *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_selection_finish (
    MaliitContext *proxy,
    gboolean *out_unnamed_arg0,
    gchar **out_unnamed_arg1,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_selection_sync (
    MaliitContext *proxy,
    gboolean *out_unnamed_arg0,
    gchar **out_unnamed_arg1,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_set_language (
    MaliitContext *proxy,
    const gchar *arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_set_language_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_set_language_sync (
    MaliitContext *proxy,
    const gchar *arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_notify_extended_attribute_changed (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    const gchar *arg_unnamed_arg1,
    const gchar *arg_unnamed_arg2,
    const gchar *arg_unnamed_arg3,
    GVariant *arg_unnamed_arg4,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_notify_extended_attribute_changed_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_notify_extended_attribute_changed_sync (
    MaliitContext *proxy,
    gint arg_unnamed_arg0,
    const gchar *arg_unnamed_arg1,
    const gchar *arg_unnamed_arg2,
    const gchar *arg_unnamed_arg3,
    GVariant *arg_unnamed_arg4,
    GCancellable *cancellable,
    GError **error);

void maliit_context_call_plugin_settings_loaded (
    MaliitContext *proxy,
    GVariant *arg_unnamed_arg0,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_context_call_plugin_settings_loaded_finish (
    MaliitContext *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_context_call_plugin_settings_loaded_sync (
    MaliitContext *proxy,
    GVariant *arg_unnamed_arg0,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define MALIIT_TYPE_CONTEXT_PROXY (maliit_context_proxy_get_type ())
#define MALIIT_CONTEXT_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MALIIT_TYPE_CONTEXT_PROXY, MaliitContextProxy))
#define MALIIT_CONTEXT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), MALIIT_TYPE_CONTEXT_PROXY, MaliitContextProxyClass))
#define MALIIT_CONTEXT_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MALIIT_TYPE_CONTEXT_PROXY, MaliitContextProxyClass))
#define MALIIT_IS_CONTEXT_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MALIIT_TYPE_CONTEXT_PROXY))
#define MALIIT_IS_CONTEXT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), MALIIT_TYPE_CONTEXT_PROXY))

typedef struct _MaliitContextProxy MaliitContextProxy;
typedef struct _MaliitContextProxyClass MaliitContextProxyClass;
typedef struct _MaliitContextProxyPrivate MaliitContextProxyPrivate;

struct _MaliitContextProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  MaliitContextProxyPrivate *priv;
};

struct _MaliitContextProxyClass
{
  GDBusProxyClass parent_class;
};

GType maliit_context_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MaliitContextProxy, g_object_unref)
#endif

void maliit_context_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MaliitContext *maliit_context_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
MaliitContext *maliit_context_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void maliit_context_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MaliitContext *maliit_context_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
MaliitContext *maliit_context_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define MALIIT_TYPE_CONTEXT_SKELETON (maliit_context_skeleton_get_type ())
#define MALIIT_CONTEXT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MALIIT_TYPE_CONTEXT_SKELETON, MaliitContextSkeleton))
#define MALIIT_CONTEXT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), MALIIT_TYPE_CONTEXT_SKELETON, MaliitContextSkeletonClass))
#define MALIIT_CONTEXT_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MALIIT_TYPE_CONTEXT_SKELETON, MaliitContextSkeletonClass))
#define MALIIT_IS_CONTEXT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MALIIT_TYPE_CONTEXT_SKELETON))
#define MALIIT_IS_CONTEXT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), MALIIT_TYPE_CONTEXT_SKELETON))

typedef struct _MaliitContextSkeleton MaliitContextSkeleton;
typedef struct _MaliitContextSkeletonClass MaliitContextSkeletonClass;
typedef struct _MaliitContextSkeletonPrivate MaliitContextSkeletonPrivate;

struct _MaliitContextSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  MaliitContextSkeletonPrivate *priv;
};

struct _MaliitContextSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType maliit_context_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MaliitContextSkeleton, g_object_unref)
#endif

MaliitContext *maliit_context_skeleton_new (void);


G_END_DECLS

#endif /* __MALIIT_GLIB_MALIITCONTEXT_H__ */
