/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __MALIIT_GLIB_MALIITSERVER_H__
#define __MALIIT_GLIB_MALIITSERVER_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for com.meego.inputmethod.uiserver1 */

#define MALIIT_TYPE_SERVER (maliit_server_get_type ())
#define MALIIT_SERVER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MALIIT_TYPE_SERVER, MaliitServer))
#define MALIIT_IS_SERVER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MALIIT_TYPE_SERVER))
#define MALIIT_SERVER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), MALIIT_TYPE_SERVER, MaliitServerIface))

struct _MaliitServer;
typedef struct _MaliitServer MaliitServer;
typedef struct _MaliitServerIface MaliitServerIface;

struct _MaliitServerIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_activate_context) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_app_orientation_about_to_change) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gint arg_angle);

  gboolean (*handle_app_orientation_changed) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gint arg_angle);

  gboolean (*handle_hide_input_method) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_load_plugin_settings) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_descriptionLanguage);

  gboolean (*handle_mouse_clicked_on_preedit) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gint arg_posX,
    gint arg_posY,
    gint arg_preeditRectX,
    gint arg_preeditRectY,
    gint arg_preeditRectWidth,
    gint arg_preeditRectHeight);

  gboolean (*handle_process_key_event) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gint arg_keyType,
    gint arg_keyCode,
    gint arg_modifiers,
    const gchar *arg_text,
    gboolean arg_autoRepeat,
    gint arg_count,
    guint arg_nativeScanCode,
    guint arg_nativeModifiers,
    guint arg_time);

  gboolean (*handle_register_attribute_extension) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gint arg_id,
    const gchar *arg_fileName);

  gboolean (*handle_reset) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_set_copy_paste_state) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_copyAvailable,
    gboolean arg_pasteAvailable);

  gboolean (*handle_set_extended_attribute) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gint arg_id,
    const gchar *arg_target,
    const gchar *arg_targetItem,
    const gchar *arg_attribute,
    GVariant *arg_value);

  gboolean (*handle_set_preedit) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_text,
    gint arg_cursorPos);

  gboolean (*handle_show_input_method) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_unregister_attribute_extension) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    gint arg_id);

  gboolean (*handle_update_widget_information) (
    MaliitServer *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_stateInformation,
    gboolean arg_focusChanged);

  void (*invoke_action) (
    MaliitServer *object,
    const gchar *arg_action,
    const gchar *arg_sequence);

};

GType maliit_server_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *maliit_server_interface_info (void);
guint maliit_server_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void maliit_server_complete_activate_context (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_show_input_method (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_hide_input_method (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_mouse_clicked_on_preedit (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_set_preedit (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_update_widget_information (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_reset (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_app_orientation_about_to_change (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_app_orientation_changed (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_set_copy_paste_state (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_process_key_event (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_register_attribute_extension (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_unregister_attribute_extension (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_set_extended_attribute (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);

void maliit_server_complete_load_plugin_settings (
    MaliitServer *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void maliit_server_emit_invoke_action (
    MaliitServer *object,
    const gchar *arg_action,
    const gchar *arg_sequence);



/* D-Bus method calls: */
void maliit_server_call_activate_context (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_activate_context_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_activate_context_sync (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_show_input_method (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_show_input_method_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_show_input_method_sync (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_hide_input_method (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_hide_input_method_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_hide_input_method_sync (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_mouse_clicked_on_preedit (
    MaliitServer *proxy,
    gint arg_posX,
    gint arg_posY,
    gint arg_preeditRectX,
    gint arg_preeditRectY,
    gint arg_preeditRectWidth,
    gint arg_preeditRectHeight,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_mouse_clicked_on_preedit_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_mouse_clicked_on_preedit_sync (
    MaliitServer *proxy,
    gint arg_posX,
    gint arg_posY,
    gint arg_preeditRectX,
    gint arg_preeditRectY,
    gint arg_preeditRectWidth,
    gint arg_preeditRectHeight,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_set_preedit (
    MaliitServer *proxy,
    const gchar *arg_text,
    gint arg_cursorPos,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_set_preedit_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_set_preedit_sync (
    MaliitServer *proxy,
    const gchar *arg_text,
    gint arg_cursorPos,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_update_widget_information (
    MaliitServer *proxy,
    GVariant *arg_stateInformation,
    gboolean arg_focusChanged,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_update_widget_information_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_update_widget_information_sync (
    MaliitServer *proxy,
    GVariant *arg_stateInformation,
    gboolean arg_focusChanged,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_reset (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_reset_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_reset_sync (
    MaliitServer *proxy,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_app_orientation_about_to_change (
    MaliitServer *proxy,
    gint arg_angle,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_app_orientation_about_to_change_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_app_orientation_about_to_change_sync (
    MaliitServer *proxy,
    gint arg_angle,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_app_orientation_changed (
    MaliitServer *proxy,
    gint arg_angle,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_app_orientation_changed_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_app_orientation_changed_sync (
    MaliitServer *proxy,
    gint arg_angle,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_set_copy_paste_state (
    MaliitServer *proxy,
    gboolean arg_copyAvailable,
    gboolean arg_pasteAvailable,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_set_copy_paste_state_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_set_copy_paste_state_sync (
    MaliitServer *proxy,
    gboolean arg_copyAvailable,
    gboolean arg_pasteAvailable,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_process_key_event (
    MaliitServer *proxy,
    gint arg_keyType,
    gint arg_keyCode,
    gint arg_modifiers,
    const gchar *arg_text,
    gboolean arg_autoRepeat,
    gint arg_count,
    guint arg_nativeScanCode,
    guint arg_nativeModifiers,
    guint arg_time,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_process_key_event_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_process_key_event_sync (
    MaliitServer *proxy,
    gint arg_keyType,
    gint arg_keyCode,
    gint arg_modifiers,
    const gchar *arg_text,
    gboolean arg_autoRepeat,
    gint arg_count,
    guint arg_nativeScanCode,
    guint arg_nativeModifiers,
    guint arg_time,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_register_attribute_extension (
    MaliitServer *proxy,
    gint arg_id,
    const gchar *arg_fileName,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_register_attribute_extension_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_register_attribute_extension_sync (
    MaliitServer *proxy,
    gint arg_id,
    const gchar *arg_fileName,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_unregister_attribute_extension (
    MaliitServer *proxy,
    gint arg_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_unregister_attribute_extension_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_unregister_attribute_extension_sync (
    MaliitServer *proxy,
    gint arg_id,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_set_extended_attribute (
    MaliitServer *proxy,
    gint arg_id,
    const gchar *arg_target,
    const gchar *arg_targetItem,
    const gchar *arg_attribute,
    GVariant *arg_value,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_set_extended_attribute_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_set_extended_attribute_sync (
    MaliitServer *proxy,
    gint arg_id,
    const gchar *arg_target,
    const gchar *arg_targetItem,
    const gchar *arg_attribute,
    GVariant *arg_value,
    GCancellable *cancellable,
    GError **error);

void maliit_server_call_load_plugin_settings (
    MaliitServer *proxy,
    const gchar *arg_descriptionLanguage,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean maliit_server_call_load_plugin_settings_finish (
    MaliitServer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean maliit_server_call_load_plugin_settings_sync (
    MaliitServer *proxy,
    const gchar *arg_descriptionLanguage,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define MALIIT_TYPE_SERVER_PROXY (maliit_server_proxy_get_type ())
#define MALIIT_SERVER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MALIIT_TYPE_SERVER_PROXY, MaliitServerProxy))
#define MALIIT_SERVER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), MALIIT_TYPE_SERVER_PROXY, MaliitServerProxyClass))
#define MALIIT_SERVER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MALIIT_TYPE_SERVER_PROXY, MaliitServerProxyClass))
#define MALIIT_IS_SERVER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MALIIT_TYPE_SERVER_PROXY))
#define MALIIT_IS_SERVER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), MALIIT_TYPE_SERVER_PROXY))

typedef struct _MaliitServerProxy MaliitServerProxy;
typedef struct _MaliitServerProxyClass MaliitServerProxyClass;
typedef struct _MaliitServerProxyPrivate MaliitServerProxyPrivate;

struct _MaliitServerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  MaliitServerProxyPrivate *priv;
};

struct _MaliitServerProxyClass
{
  GDBusProxyClass parent_class;
};

GType maliit_server_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MaliitServerProxy, g_object_unref)
#endif

void maliit_server_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MaliitServer *maliit_server_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
MaliitServer *maliit_server_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void maliit_server_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MaliitServer *maliit_server_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
MaliitServer *maliit_server_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define MALIIT_TYPE_SERVER_SKELETON (maliit_server_skeleton_get_type ())
#define MALIIT_SERVER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MALIIT_TYPE_SERVER_SKELETON, MaliitServerSkeleton))
#define MALIIT_SERVER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), MALIIT_TYPE_SERVER_SKELETON, MaliitServerSkeletonClass))
#define MALIIT_SERVER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MALIIT_TYPE_SERVER_SKELETON, MaliitServerSkeletonClass))
#define MALIIT_IS_SERVER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MALIIT_TYPE_SERVER_SKELETON))
#define MALIIT_IS_SERVER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), MALIIT_TYPE_SERVER_SKELETON))

typedef struct _MaliitServerSkeleton MaliitServerSkeleton;
typedef struct _MaliitServerSkeletonClass MaliitServerSkeletonClass;
typedef struct _MaliitServerSkeletonPrivate MaliitServerSkeletonPrivate;

struct _MaliitServerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  MaliitServerSkeletonPrivate *priv;
};

struct _MaliitServerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType maliit_server_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MaliitServerSkeleton, g_object_unref)
#endif

MaliitServer *maliit_server_skeleton_new (void);


G_END_DECLS

#endif /* __MALIIT_GLIB_MALIITSERVER_H__ */
